clear_active_and_set_next

Function clear_active_and_set_next 

pub fn clear_active_and_set_next()
Clears the timer slot for the currently active timer and sets the next timer or disables it if no timer is pending.