TimerList

Struct TimerList 

pub struct TimerList(/* private fields */);

Implementations

Source

impl TimerList

pub fn new() -> Self

pub fn slot_by_source_mut(&mut self, source: Source) -> &mut Slot

Mutably get the slot for a source.

pub fn next_timer(&self) -> &Slot

pub fn next_timer_mut(&mut self) -> &mut Slot

Find and mutably get the next timer to fire (may return one that is not currently set if none are set).

pub fn adjust_by(&mut self, offset: u64)

Adjust all wakeup times by a specific offset.