pub fn clear_active_and_set_next()Expand description
Clears the timer slot for the currently active timer and sets the next timer or disables it if no timer is pending.
pub fn clear_active_and_set_next()Clears the timer slot for the currently active timer and sets the next timer or disables it if no timer is pending.