pub struct Slot { /* private fields */ }Expand description
A slot in the timer list. Each source is represented once. This is so that we can have multiple timers at the same time with only one hardware timer.