pub struct TimerList(/* private fields */);Implementations
Sourceimpl TimerList
impl TimerList
pub fn new() -> Self
Sourcepub fn slot_by_source_mut(&mut self, source: Source) -> &mut Slot
pub fn slot_by_source_mut(&mut self, source: Source) -> &mut Slot
Mutably get the slot for a source.
pub fn next_timer(&self) -> &Slot
Sourcepub fn next_timer_mut(&mut self) -> &mut Slot
pub fn next_timer_mut(&mut self) -> &mut Slot
Find and mutably get the next timer to fire (may return one that is not currently set if none are set).